#
# spec file for package doxywizard
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           doxywizard
Version:        1.8.14
Release:        lp152.4.3.1
Summary:        Graphical User Interface for Doxygen
# qtools are used for building and they are GPL-3.0 licensed
License:        GPL-2.0+ AND GPL-3.0
Group:          Development/Tools/Doc Generators
Url:            http://www.stack.nl/~dimitri/doxygen/
Source:         http://ftp.stack.nl/pub/users/dimitri/doxygen-%{version}.src.tar.gz
Source1:        doxywizard.desktop
# PATCH-FIX-UPSTREAM: add missing returns to non-void functions
Patch3:         vhdlparser-no-return.patch
BuildRequires:  bison
BuildRequires:  cmake >= 2.8.12
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  python3-base
BuildRequires:  python3-xml
BuildRequires:  update-desktop-files
Requires:       doxygen = %{version}
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
%if 0%{?suse_version} > 1230 && 0%{?suse_version} != 1315
# for make tests
BuildRequires:  libxml2-tools
BuildRequires:  texlive-bibtex
%endif

%description
Doxywizard is a graphical front-end to read/edit/write doxygen
configuration files.

%prep
%setup -q -n doxygen-%{version}
%patch3 -p1

%build
%cmake \
    -Dbuild_wizard=ON \
    -DCMAKE_EXE_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,relro,-z,now" \
    -DCMAKE_MODULE_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,relro,-z,now" \
    -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,relro,-z,now"
%make_jobs

%if 0%{?suse_version} > 1230 && 0%{?suse_version} != 1315
%check
export LANG=C.UTF-8
# testing doxygen package here to avoid build
# cycle between latex and doxygen
pushd build
make tests %{?_smp_mflags}
popd
%endif

%install
%cmake_install
rm %{buildroot}%{_bindir}/doxygen
mkdir -p %{buildroot}%{_mandir}/man1/
install -m 644 doc/doxywizard.1 %{buildroot}%{_mandir}/man1/
%suse_update_desktop_file -i doxywizard Development Documentation

%files
%attr(755,root,root) %{_bindir}/doxywizard
%{_datadir}/applications/doxywizard.desktop
%{_mandir}/man1/doxywizard.1%{ext_man}

%changelog
* Thu Apr 22 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- remove explicit -fPIC from build flags, because this breaks our
  gcc-PIE compiler profile (bsc#1184122), resulting in a non-PIE
  /usr/bin/doxywizard.
* Fri Jan  5 2018 dimstar@opensuse.org
- Export LANG=C.UTF-8 before running the test suite. Python3 is
  kinda strict and generally expects an UTF8 terminal.
* Wed Jan  3 2018 tchvatal@suse.com
- Update to 1.8.14:
  * Many fixes during the one year development cycle:
    http://www.stack.nl/~dimitri/doxygen/manual/changelog.html#log_1_8_14
- Switch to python3 instead of python2
- Refresh patch vhdlparser-no-return.patch
- Use qt5 doxywizard even on leaps
* Fri Nov 10 2017 mpluskal@suse.com
- Update licensing information
* Tue Nov  7 2017 mpluskal@suse.com
- Explicitly require python2 for building
- Use more cmake macros
- Run spec-cleaner
* Wed Feb 22 2017 foss@grueninger.de
- Revert erroneous change of required CMake version
* Tue Feb 14 2017 foss@grueninger.de
- Update to 1.8.13
  See changelog at http://www.stack.nl/~dimitri/doxygen/manual/changelog.html#log_1_8_13
* Tue Sep  6 2016 foss@grueninger.de
- Update to 1.8.12
  See changelog at http://www.stack.nl/~dimitri/doxygen/manual/changelog.html
* Sun Feb 21 2016 crrodriguez@opensuse.org
- Build against QT5 in newer products
- Do not link with -pie as we are not compiling with -fPIE
* Tue Jan  5 2016 pgajdos@suse.com
- fix build after update
* Tue Jan  5 2016 foss@grueninger.de
- Update to 1.8.11
  See changelog at http://www.stack.nl/~dimitri/doxygen/manual/changelog.html
- Update patch vhdlparser-no-return.patch
- Remove patch doxygen-no-shared-libs.patch which is included
  in upstream
* Thu Aug 27 2015 mpluskal@suse.com
- Move checks to doxywizard package to avoid build cycle
* Fri Aug 21 2015 tchvatal@suse.com
- Set proper minimal cmake version required
- Use system stack for cmake params and obey cflags
- Add patch to build required static libs:
  * doxygen-no-shared-libs.patch
- Refresh patch:
  * doxygen-no-lowercase-man-names.patch
- Add patch to avoid no-return-in-nonvoid function error:
  * vhdlparser-no-return.patch
* Mon Aug 17 2015 pgajdos@suse.com
- updated to 1.8.10, see doxygen.changes
- move tests to doxygen.spec
- remove doxywizard-1.5.9-flex.patch
* Fri Feb 20 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Enable tests
* Fri Feb  6 2015 mpluskal@suse.com
- Update to 1.8.9.1:
  * bugfix releas, see
    http://www.stack.nl/~dimitri/doxygen/manual/changelog.html
    for details
* Thu Aug 28 2014 andreas.stieger@gmx.de
- Doxygen 1.8.8
- New features:
  * Support for PlantUML
  * Add BREAD_CRUMB_TRAIL
- A selection of bug fixes and updates as listed in
  http://www.stack.nl/~dimitri/doxygen/manual/changelog.html#log_1_8_8
* Tue May 13 2014 pgajdos@suse.com
- updated to 1.8.7:
  * many bugfixes and features, see
    http://www.stack.nl/~dimitri/doxygen/manual/changelog.html
    for details
* Thu Jan  2 2014 pgajdos@suse.com
- updated to 1.8.6:
  * many bugfixes and features, see
    http://www.stack.nl/~dimitri/doxygen/manual/changelog.html
    for details
* Mon Aug 26 2013 pgajdos@suse.com
- updated to 1.8.5:
  * Added SOURCE_TOOLTIPS option for advanced tooltip support while
    source browsing.
  * bugfixes
* Mon May 20 2013 pgajdos@suse.com
- updated to 1.8.4:
  * id 686384: When INLINE_SIMPLE_STRUCTS is enabled, also structs
    with simple typedefs will be inlined.
  * Doxywizard: scrolling with mouse wheel no longer affects the
    values in the expert view.
  * id 681733: More consistent warnings and errors.
  * Added support for "clang assisted parsing", which allows the
    code to also be parsed via libclang (C/C++ frontend of LLVM)
    and can improve the quality of the syntax highting,
    cross-references, and call graphs, especially for template
    heavy C++ code. To enable this feature you have to configure
    doxygen with the --with-libclang option. Then you get two new
    configuration options: CLANG_ASSISTED_PARSING to enable or
    disable parsing via clang and CLANG_OPTIONS to pass additional
    compiler options needed to compile the files. Note that
    enabling this feature has a significant performance penality.
  * Included patch donated by Intel which adds Docbook support.
    This can be enabled via GENERATE_DOCBOOK and the output
    location can be controlled using DOCBOOK_OUTPUT. Docbook
    specific sections can be added using
    \docbookonly ... \enddocbookonly
  * Added support for UNO IDL (interace language used in
    Open/Libre Office), thanks to Michael Stahl for the patch.
  * Included patch by Adrian Negreanu which stores data gathered
    by doxygen in a sqlite3 database. Currently still work in
    progress and can only be enabled using --with-sqlite3 during
    ./configure.
  * For interactive SVG graphs, edges are now highlighted when
    hovered by the mouse.
  * Include patch by Adrian Negreanu to show duration statistics
    after a run. You can enable this by running doxygen with the
    "-d Time" option.
  * Included patch by Markus Geimer which adds a new option
    LATEX_EXTRA_FILES which works similarily to HTML_EXTRA_FILES
    in that it copied specified files to the LaTeX output
    directory.
  * etc., see http://www.stack.nl/~dimitri/doxygen/manual/changelog.html
* Tue Mar 26 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Tue Jan 22 2013 pgajdos@suse.com
- updated to 1.8.3.1:
  Changes
  * Changed to way the search results for multiple projects can
    be linked together. A project is now no longer identified by
    the tag files name but via new option EXTERNAL_SEARCH_ID giving
    a bit more flexibility.
  * Disabled the disk cache for member data. Allows removing quite
    some complexity in doxygen and is not really needed now that
    64bit systems with >4GB RAM are becoming more common. Let me
    know if you think you benefit from this caching.
  * id 691607: Using $relpath$ in a custom footer could lead to
    ambiguities when followed by a name that could also be a marker,
    like 'search'. Now $relpath^ should be used instead. $relpath$
    is still supported for backward compatibility.
  New features
  * You can now use EXTENSION_MAPPING on files without any
    extension using no_extension as placeholder (thanks to
    Jason Majors for the patch).
  * To make navindex section inside a layout file that
    links to a specific URL you can use usergroup with the
    url attribute.
  * To make navindex section without any link inside a
    layout file you can use usergroup with special title
    [none].
  Details at: http://www.stack.nl/~dimitri/doxygen/changelog.html
* Mon Aug 20 2012 pgajdos@suse.com
- updated to 1.8.2:
    changes
  * Using a fenched block (~~~~) in Markdown without explicit
    extension will now be interpreted as a @code..@endcode block
    instead of @verbatim..@endverbatim.
  * Classes inheriting from an class that is outside the scope
    of doxygen are still shown in diagrams. This does not hold
    for usage relations.
    new features
  * Added support for C++11.
  * Made several improvements to the way Objective-C categories
    and protocols are handled:
  * Added option HTML_EXTRA_STYLESHEET which allows adding an
    additional stylesheet without completely replacing
    doxygen.css.
  * Added option AUTOLINK_SUPPORT which can be used to
    enable/disable autolinking globally.
  * Included language updates for Czech, Spanish, Greek, Slovak,
    and Esparanto.
    etc. see http://www.stack.nl/~dimitri/doxygen/changelog.html
* Fri Jul 13 2012 pgajdos@suse.com
- updated to 1.8.1.2:
  changes
  * doxygen now strips the leading indentation shared by the lines
    in a @code..@endcode block.
  * id 678218: Changed title of the SVG graphs from 'G' to the root
    node of the graph.
  * Integrated the root navigation tree in navtree.js for faster
    loading
  * When the navigation tree is enabled, clicking jump to a line
    in the source code view will now highlight the line.
  features
  * Added button in the navigation tree to allow enabling/disabling
    syncing the navigation tree with the content.
  * Extended the number of HTML entities with Greek letters and
    other symbols (thanks to Charles Karney for the patch).
  * id 663645: Added support for C++11 strongly typed enums (enum
    class E { ... }).
  * VHDL code now has a new Design Overview page (thanks for
    Martin Kreis for the patch). Requires HAVE_DOT=YES, and
    DOT_IMAGE_FORMAT=svg.
  * id 677678: Added support for strong and weak attributes in
    Objective-C properties.
  * bugfixes
- for details see http://www.stack.nl/~dimitri/doxygen/changelog.html
* Mon Apr 16 2012 pgajdos@suse.com
- updated to 1.8.0svn20120416:
  * fixed crash [bnc#755402]
* Tue Feb 28 2012 pgajdos@suse.com
- removing unneeded warnings.patch
* Mon Feb 27 2012 pgajdos@suse.com
- updated to 1.8.0:
  * Auto list items can now consist of multiple paragraphs.
  * When UML_LOOK is enabled, relations shown on the edge of a
    graph are not shown as attributes.
  * Updated the manual and improved the look.
  * Latex: made the margins of latex page layout smaller using the
    geometry package.
  * etc., see http://www.stack.nl/~dimitri/doxygen/changelog.html
* Mon Dec  5 2011 pgajdos@suse.com
- updated to 1.7.6:
  * To improve the performance of loading the navigation tree,
    the data is now split into multiple javascript files which
    are loaded dynamically.
  * The selected member is now briefly highlighted in the HTML
    output (when GENERATE_TREEVIEW is enabled).
  * The navigation tree (GENERATE_TREEVIEW) now shows the same
    information as the index.
  * The navindex section of layout now also controls what is
    shown in the navigation tree.
  * Improved HTML output support for IE9.
  * Included redesigned VHDL parser (thanks to Martin Kreis
    for the patch)
  * When a class/structs has many (>15) members of the same type,
    only the first 10 are shown in the UML diagram.
  * Made the output of the javascript based search engine more
    compact.
  * Update of the French translation.
  * id 607305: Added support for PHP heredoc and nowdoc constructs.
  * Added support for cross-referencing in case of operator->
    overloading. This includes support for std::auto_ptr,
    std::smart_ptr,std::unique_ptr and std::weak_ptr when
    BUILTIN_STL_SUPPORT is enabled.
  * bugfixes
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Mon Aug 15 2011 pgajdos@novell.com
- update to 1.7.5:
  * id 641904: Function in the call graphs are now shown based on first
    appearance rather then alphabetical order.
  * id 616213: When customizing the HTML header $title now only generates
    the title excluding the project name (which can still be
    added using $projectname)
  * Improved the look of the class index: all items now have equal spacing.
  * New option INTERACTIVE_SVG which when set to YES in combination with
    DOT_IMAGE_FORMAT=svg will make doxygen generate interactive SVG
    diagrams that support zooming and panning via the mouse (only for
    large graphs).
  * Added support for the Tcl programming language (thanks to Rene Zaumseil
    and Samuel Bentley for the patch).
  * Added @copyright command.
  * added option MATHJAX_EXTENSIONS to provide additional extensions for
    MathJax (thanks to David Munger for the patch).
  * added option INLINE_SIMPLE_STRUCTS which when enabled shows the fields
    of simple classes and structs (with only public data fields) as a table
    and inline in context (file/group/namespace/class)
    provided this context is documented.
  * When using the server based search engine (SEARCHENGINE=YES and
    SERVER_BASED_SEARCH=YES) doxygen now advertises a opensearch provider
    for your project, that allows integrating the search directly in the
    search field of the browser (thanks to Phil Lello for the patch).
  * id 503239: Added new option CITE_BIB_FILES and LATEX_BIB_STYLE and a new
    command \cite, allowing you to make references to literature (as defined
    in one or more .bib files). This also works for output formats other
    than LaTeX. The tool bibtex is required for this to work though. Thanks
    to David Munger for the initial patch upon which this feature is based.
  * PHP namespaces are now shown as A\B in the output.
  * Added new \snippet command that can be used to include marked sections
    from a source file. See http://www.doxygen.org/commands.html#cmdsnippet
    for more info.
  * Added translation support for Armenian, thank to Armen Tangamyan. and
    included translation updates for a number of languages.
  * Many bug fixes, for details see
    http://www.stack.nl/~dimitri/doxygen/changelog.html.
* Wed Jul 27 2011 dmueller@suse.de
- remove explicit dependency on libdrm-devel
* Tue Mar 29 2011 pascal.bleser@opensuse.org
- update to 1.7.4 (no user-visible changes)
* Tue Jan  4 2011 pascal.bleser@opensuse.org
- update to 1.7.3:
  * new control to visually select the color of the HTML output
* Fri Nov 12 2010 mseben@gmail.com
- changed modify_footer.patch: drop suse specific HTML_FOOTER_DESCRIPTION
  option functionality, each package could use now HTML_TIMESTAMP to
  avoid putting timestamp in to generated html files
* Mon Oct 11 2010 pgajdos@novell.com
- updated to 1.7.2:
  * Changed the default font of the LaTeX output to helvetica.
  * Changed the way parameters and return values are represented
    in the LaTeX and RTF output. They are now listed using tables.
  * added support for Apple's block object extension for C/Obj-C/C++.
  * added support for detecting Python constructors and destructors.
  * id 624575: Added \endinternal command that can be used to force
    the end of a section started with \internal.
  * id 552605: Added parsing support for PHP 5.3+ style namespaces.
  * id 582532: added \mscfile command which can be used to insert a
    message sequence chart given a .msc file. Also added a new
    config option MSCFILE_DIRS to provide directories were msc
    files are searched (Thanks to Adrien for the patch).
  * Added support for type specifiers for documenting PHP
    parameters, format: "@param type $paramname docs"
  * Added support for rendering formulas in the HTML output using
    MathJax instead of using prerendered bitmaps. For this purpose
    the options USE_MATHJAX and MATHJAX_RELPATH were added.
  * Many bugfixes.
  * For details see http://www.stack.nl/~dimitri/doxygen/changelog.html.
* Fri Jun 25 2010 pascal.bleser@opensuse.org
- update to 1.7.1
* Tue Jun 15 2010 pascal.bleser@opensuse.org
- update to 1.7.0
* Sun Feb 21 2010 Nico.Laus.2001@gmx.de
- update to 1.6.3:
  - Bug fixes (ids refer to the bugzilla database)
  * id 606084: Loading a new config file in doxywizard did not
    reset all values of a previously loaded config file.
* Mon Sep  7 2009 pascal.bleser@opensuse.org
- update to 1.6.1:
  * include patch to fix problem with building rpms
  * fix doxywizard problem with GENERATE_TREEVIEW
* Fri Aug 21 2009 nico.laus.2001@gmx.de
- updated to version 1.6.0
  - Changes
  * id 580924, 541234: Replaced the PHP based search engine by a
    Javascript/DHTML based one. As a result the search feature no longer
    requires a HTTP server with PHP enabled to be usable. Searching is limited
    to symbols though, but it is now possible to filter on symbol type.
  * id 519886: Make the HTML output XHTML 1.0 compliant.
  * id 579950: Objective-C categories are now merged with their base class,
    unless there is no base class.
  * Member groups with the same header within the same scope are now merged.
    This also works for Objective-C categories.
  * Changed the LaTeX style sheet such that more of the markup is configurable.
    Please update your style sheet if you use a custom one.
  * id 584844: Treat \details inside a brief description as a new paragraph
    command.
  * Split GENERATE_TREEVIEW into two separate options: GENERATE_TREEVIEW and
    USE_INLINE_TREES.
  * Removed the dependencies on libpng and libz, doxygen now generates gifs
    again for internal class diagrams (like it did 7 years ago ;-)
  - New features
  * Added option SORT_MEMBERS_CTORS_1ST, which when enabled places the
    constructors and destructors first in an otherwise sorted list.
  * id 581518: Applied patch by Tobias Hunger that adds support for
    documenting DBus XML interface descriptions.
  * Included QtHelp patch by Karsten Heimrich which adds missing reference
    and keyword for methods.
  * Included updates for the Korean and Polish translation.
  - Bug fixes (ids refer to the gnome bugzilla database)
  * id 131989: Fixed preprocessor handling for C# code.
  * id 133418: -- was not rendered correctly for LaTeX output
  * id 157485: Missing link in todo page.
  * id 318061: Two template functions that only differed in the number of
    template arguments were seen as the same function.
  * id 443939: HIDE_UNDOC_CLASSES did not work properly.
  * id 509348: Fixed problem with syncing the information of declaration and
    definition in the presence of an extra forward declaration in the source
    code.
  * id 522193: For C# enum values were merged together if the same enum name
    was used in different scopes.
  * id 523167: Included patch to handle PROGRAM statement in Fortran as
    subroutines/functions.
  * id 554636: Remove spacing around brackets for Obj-C protocols.
  * id 557026: Included patch for fixing wrongly labeled items in docsets.
  * id 560512: Improved parser to better disambiguate nested templates ending
    with >> from the bitshift right operator.
  * id 570238: Fixed matching problem for method in nested class, where the
    outer class is a template.
  * id 581746: Segfault/realloc error when a very long path was used.
  * id 582469: documented #define with guard caused wrong documentation.
  * id 582276: Doxywizard could crash on exit in some cases.
  * id 582676: Regression: a struct ivar in ObjC class screws up method
    identification.
  * id 583213: Included patch that avoids trailing spaces in the generated
    Doxyfile template.
  * id 584192: Included VHDL patch by Martin Klein
  * id 585543: Fixed case where matching declaration and definition did not
    work correctly.
  * id 585260: The "more..." link for files was broken, since the anchor was
    not generated.
  * id 586925: Fixed parsing problem when an unpaired apostrophe appeared in
    a Python comment.
  * id 588291: Included fix for doxywizard makefile.
  * id 588587: Added missing virtual destructor to CompAccept base class.
  * id 588968: Fixed segmentation fault for specific case in PHP code.
  * Fixed some issues building for Windows.
  * id 589514: Fixed problem handling strings like a"\b" within a comment.
  * id 589616: Fixed problem matching explicitly scoped parameter in a
    template class.
  * id 590712: A namespaced with name "internal" (C++/CLI keyword) could
    confuse doxygen's C++ parser.
  * id 591749: @optional/@required attributes for Objective-C were missing
    from the XML output.
* Mon May  4 2009 mseben@suse.cz
- updated to version 1.5.9
  - New features
  * Added new option LATEX_SOURCE_CODE, which when enabled adds
    source code also to the latex output
  * Included updates for the Finnish, Romanian, Korean, German,
    Japanese, and Hongarian translation.
  * Added translation support for Esperanto.
  * Added class attribute to the \todo and \bug HTML
    code so they can be customized via CSS.
  * Added support for Æ and æ characters.
  - Bug fixes (ids refer to the gnome bugzilla database)
  * id 395169: Some links via tagfiles were not correct in
    combination with CREATE_SUBDIRS=YES
  * id 539080: Having the same comment for the declaration and
    definition of a function could result in duplicate documentation
    in case the indentation level was different.
  * id 566713: Dot font was not removed even though DOT_CLEANUP was YES.
  * id 566925: Fixed problem resolving symbolic links.
  * id 567044: Fully qualified name was not shown correctly for
    nested classes.
  * id 567375: Fixed parse problem for typedefs with redundant braces.
  * id 567535: Fixed problem when parsing operator%%= for CLI/C++ code.
  * id 567777: Fixed problem with latex output when using enums.
  * id 567990: Doxygen could crash when there was a symlink in project.
  * id 568237: Non-ascii values entered where not saved according
    to the INPUT_ENCODING.
  * id 568505: Fixed build problem for old Linux distributions.
  * id 569478: Fixed line continuation issue with the Fortran parser.
  * id 570960: C++ class defined in a .mm file was sometimes parsed
    as Objective-C code.
  * id 571013: In the wizard, editing a text field in the middle of
    the text in the expert tab caused the cursor to jump to the end
    of the line.
  * id 571096: Fixed Objective-C parsing problem when multiple
    protocol forward declarations are put on one line.
  * id 571990: Fixed compiler issue with portable_iconv by moving
    the function to a C file.
  * id 572560: Fixed parse issue when a #define is inside an enum.
  * id 572740: Fixed problem parsing C++ comments using line continuation.
  * id 573057: Included update for Swedish translator and changed
    the language code from SE to SV to comply with ISO 639.
  * id 578382: When referring to a static variable or function
    doxygen will now look at the file context in case of ambiguity.
- dropped qtdir.patch as it seems it is not needed anymore
* Mon Feb  9 2009 olh@suse.de
- compile with RPM_OPT_FLAGS again
- apply 64bit patch unconditionally
- fix compile warnings for string and signed char handling
- disable language support on ppc64
  code size too large, -mminimal-toc does not help
* Wed Jan 14 2009 nico.laus.2001@gmx.de
- updated to compile on Fedora and Mandriva
* Tue Jan  6 2009 mseben@suse.cz
- updated to version 1.5.8
  Changes
  * Completely rewrote the doxywizard. Main changes:
  * It is now based on Qt version 4. (4.3 or higher is required)
  * Different layout that allows easy switching between wizard and
    expert mode, without losing settings.
  * Running doxygen can be done without first having to save the
    configuration file.
  * For HTML output, there is a button to show the results in the
    default browser.
  * Option to change the default configuration that is used when
    you first start the wizard.
  * Non-default options are shown with red label, and there is
    context menu to reset them back to the default.-
- rewritten (*-man.patch)
- spec file clean-up, added libqt4-devel to BuildRequires
- fixed qmake and moc path (*-qtdir.patch)
* Tue Jul 15 2008 anosek@suse.cz
- updated to version 1.5.6
* Tue Oct 30 2007 anosek@suse.cz
- updated to version 1.5.4
* Fri Jul 27 2007 anosek@suse.cz
- updated to version 1.5.3
* Tue Apr 10 2007 anosek@suse.cz
- fixed build of Doxywizard
* Thu Apr  5 2007 anosek@suse.cz
- updated to version 1.5.2
* Thu Mar 29 2007 mmarek@suse.de
- added flex and bison to buildrequires
* Mon Feb  5 2007 anosek@suse.cz
- updated to version 1.5.1
  * fixed build (makefile.patch)
* Wed Oct 18 2006 anosek@suse.cz
- updated to version 1.5.0
  * bugfixes
* Mon Jun 26 2006 mmarek@suse.cz
- updated to 1.4.7
  * new CALLER_GRAPH option to add called-by graph to functions
  * new REFERENCES_LINK_SOURCE option to set whether function names
    in REFERENCES_RELATION and REFERENCED_BY_RELATION link to
    source or documentation
  * doxywizard asks for confirmation before overwriting files in
    the save dialog
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 mmarek@suse.cz
- remove %%%%_lib fix, which isn't needed anymore and actually breaks
  build on 64bit
* Thu Jan  5 2006 mmarek@suse.cz
- use make -j
- add -fno-strict-aliasing
* Mon Jan  2 2006 mmarek@suse.cz
- update to 1.4.6
* Mon Oct 10 2005 mmarek@suse.cz
- update to 1.4.5
* Tue Sep 20 2005 mmarek@suse.cz
- fix qtools to build with gcc-4.1.0
* Thu Jul 28 2005 postadal@suse.cz
- updated to version 1.4.4
  * added man pages
- removed obsoleted qt-mt patch
* Sat Jan 22 2005 ro@suse.de
- fix build (qt-mt instead of qt)
* Wed Jan 12 2005 postadal@suse.cz
- updated to version 1.4.1
* Tue Aug 31 2004 postadal@suse.cz
- fixed for new flex
* Tue Aug  3 2004 postadal@suse.cz
- updated to version 1.3.8
* Tue Apr 27 2004 postadal@suse.cz
- doxywizard split off (qt3 dependency)
